import { OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Observable } from 'rxjs';
import { PoBreadcrumb, PoDialogService, PoDynamicFormComponent, PoGridComponent, PoGridRowActions, PoLanguageService, PoNotificationService, PoPageAction, PoThemeService } from '@po-ui/ng-components';
import { PoPageCustomizationService } from '../../services/po-page-customization/po-page-customization.service';
import { PoPageDynamicService } from '../../services/po-page-dynamic/po-page-dynamic.service';
import { PoPageDynamicEditActions } from './interfaces/po-page-dynamic-edit-actions.interface';
import { PoPageDynamicEditField } from './interfaces/po-page-dynamic-edit-field.interface';
import { PoPageDynamicEditLiterals } from './interfaces/po-page-dynamic-edit-literals.interface';
import { PoPageDynamicEditOptions } from './interfaces/po-page-dynamic-edit-options.interface';
import { PoPageDynamicEditActionsService } from './po-page-dynamic-edit-actions.service';
import * as i0 from "@angular/core";
export declare const poNotificationType: string[];
export declare const poNotificationTypeDefault = "warning";
export declare const poPageDynamicEditLiteralsDefault: {
    en: PoPageDynamicEditLiterals;
    es: PoPageDynamicEditLiterals;
    pt: PoPageDynamicEditLiterals;
    ru: PoPageDynamicEditLiterals;
};
/**
 * @description
 *
 * O `po-page-dynamic-edit` é uma página que pode servir para editar ou criar novos registros,
 * o mesmo também suporta metadados conforme especificado na documentação.
 *
 * ### Utilização via rota
 *
 * Ao utilizar as rotas para inicializar o template, o `page-dynamic-edit` disponibiliza propriedades que devem ser fornecidas no arquivo de configuração de rotas da aplicação, para
 * poder especificar o endpoint dos dados e dos metadados que serão carregados na inicialização.
 *
 * Exemplo de utilização:
 *
 * Arquivo de configuração de rotas da aplicação: `app-routing.module.ts`
 * ```
 * const routes: Routes = [
 * {
 *   path: 'people',
 *   component: PoPageDynamicEditComponent,
 *   data: {
 *     serviceApi: 'http://localhost:3000/v1/people', // endpoint dos dados
 *     serviceMetadataApi: 'http://localhost:3000/v1/metadata', // endpoint dos metadados utilizando o método HTTP Get
 *     serviceLoadApi: 'http://localhost:3000/load-metadata' // endpoint de customizações dos metadados utilizando o método HTTP Post
 *   }
 *  },
 *  {
 *   path: 'home',
 *   component: HomeExampleComponent
 *  }
 * ];
 *
 * ```
 * O componente primeiro irá carregar o metadado da rota definida na propriedade serviceMetadataApi
 * e depois irá buscar da rota definida na propriedade serviceLoadApi.
 *
 * A requisição dos metadados é feita na inicialização do template para buscar os metadados da página passando o
 * tipo do metadado esperado e a versão cacheada pelo browser.
 *
 * > Caso o servidor retornar um erro ao recuperar os metadados, serão repassados os metadados salvos em cache,
 * se o cache não existir será disparada uma notificação.
 *
 * Para carregar com um recurso já existente, deve-se ser incluído um parâmetro na rota chamado `id`:
 *
 * ```
 * {
 *   path: 'people/:id',
 *   component: PoPageDynamicEditComponent,
 *   data: {
 *     serviceApi: 'http://localhost:3000/v1/people', // endpoint dos dados
 *     serviceMetadataApi: 'http://localhost:3000/v1/metadata', // endpoint dos metadados
 *     serviceLoadApi: 'http://localhost:3000/load-metadata' // endpoint de customizações dos metadados
 *   }
 * }
 * ```
 *
 * A requisição dos metadados é feita na inicialização do template para buscar os metadados da página passando o
 * tipo do metadado esperado e a versão cacheada pelo browser.
 *
 * O formato esperado na resposta da requisição está especificado na interface
 * [PoPageDynamicEditMetadata](/documentation/po-page-dynamic-edit#po-page-dynamic-edit-metadata). Por exemplo:
 *
 * ```
 *  {
 *   version: 1,
 *   title: 'Person edit',
 *   fields: [
 *     { property: 'id', key: true, disabled: true },
 *     { property: 'status' },
 *     { property: 'name' },
 *     { property: 'nickname' },
 *     { property: 'birthdate', label: 'Birth date' },
 *     { property: 'genre' },
 *     { property: 'city' },
 *     { property: 'country' }
 *   ]
 * }
 * ```
 *
 * > Caso o endpoint dos metadados não seja especificado, será feito uma requisição utilizando o `serviceApi` da seguinte forma:
 * ```
 * GET {end-point}/metadata?type=edit&version={version}
 * ```
 *
 * @example
 *
 * <example name="po-page-dynamic-edit-basic" title="PO Page Dynamic Edit Basic">
 *  <file name="sample-po-page-dynamic-edit-basic/sample-po-page-dynamic-edit-basic.component.html"> </file>
 *  <file name="sample-po-page-dynamic-edit-basic/sample-po-page-dynamic-edit-basic.component.ts"> </file>
 * </example>
 *
 * <example name="po-page-dynamic-edit-user" title="PO Page Dynamic Edit - User">
 *  <file name="sample-po-page-dynamic-edit-user/sample-po-page-dynamic-edit-user.component.html"> </file>
 *  <file name="sample-po-page-dynamic-edit-user/sample-po-page-dynamic-edit-user.component.ts"> </file>
 * </example>
 */
export declare class PoPageDynamicEditComponent implements OnInit, OnDestroy {
    private router;
    private activatedRoute;
    private poNotification;
    private poDialogService;
    private poPageDynamicService;
    private poPageCustomizationService;
    private poPageDynamicEditActionsService;
    private poThemeService;
    dynamicForm: PoDynamicFormComponent;
    gridDetail: PoGridComponent;
    /** Objeto com propriedades do breadcrumb. */
    breadcrumb?: PoBreadcrumb;
    /**
     * @description
     *
     * Endpoint usado pelo template para requisição do recurso que será exibido para edição.
     *
     * Para as ações de `save` e `saveNew`, será feito uma requisição de criação nesse mesmo endpoint passando os valores
     * preenchidos pelo usuário via payload.
     *
     * > `POST {end-point}`
     *
     * ```
     *  <po-page-dynamic-edit
     *    [p-actions]="{ save: '/', saveNew: 'new' }"
     *    [p-fields]="[ { property: 'name' }, { property: 'city' } ]"
     *    p-service="/api/po-samples/v1/people"
     *    ...>
     *  </po-page-dynamic-edit>
     * ```
     *
     * Resquisição disparada, onde a propriedade `name` e `city` foram preenchidas:
     *
     * ```
     *  POST /api/po-samples/v1/people HTTP/1.1
     *  Host: localhost:4000
     *  Connection: keep-alive
     *  Accept: application/json, text/plain
     *  ...
     * ```
     *
     * Request payload:
     *
     * ```
     * { "name": "Fulano", "city": "Smallville" }
     * ```
     *
     * Caso queira que o template carregue um recurso já existente, deve-se ser incluído um parametro na rota chamado `id`.
     *
     * Exemplo de configuração de rota:
     *
     * ```
     *  RouterModule.forRoot([
     *    ...
     *    { path: 'edit/:id', component: PersonEditComponent },
     *    ...
     *  ],
     * ```
     *
     * Baseado nisso, na inicialização do template, será disparado uma requisição para buscar o recurso que será editado.
     *
     * > `GET {end-point}/{id}`
     *
     * Nos métodos de `save` e `saveNew`, ao invés de um `POST`, será disparado um `PUT`.
     *
     * Resquisição disparada, onde a propriedade `name` e `city` foram preenchidas / atualizadas, e o `id` da url é 2:
     *
     * ```
     *  PUT /api/po-samples/v1/people/2 HTTP/1.1
     *  Host: localhost:4000
     *  Connection: keep-alive
     *  Accept: application/json, text/plain
     *  ...
     * ```
     *
     * Request payload:
     *
     * ```
     * { "name": "Fulano", "city": "Metropolis" }
     * ```
     */
    serviceApi: string;
    /** Título da página. */
    title: string;
    /**
     * Função ou serviço que será executado na inicialização do componente.
     *
     * A propriedade aceita os seguintes tipos:
     * - `string`: *Endpoint* usado pelo componente para requisição via `POST`.
     * - `function`: Método que será executado.
     *
     * O retorno desta função deve ser do tipo `PoPageDynamicEditOptions`,
     * onde o usuário poderá customizar novos campos, breadcrumb, title e actions
     *
     * Por exemplo:
     *
     * ```
     * getPageOptions(): PoPageDynamicEditOptions {
     * return {
     *   actions:
     *     { cancel: false, save: 'save/:id', saveNew: 'saveNew' },
     *   fields: [
     *     { property: 'idCard', gridColumns: 6 }
     *   ]
     * };
     * }
     *
     * ```
     * Para referenciar a sua função utilize a propriedade `bind`, por exemplo:
     * ```
     *  [p-load]="onLoadOptions.bind(this)"
     * ```
     */
    onLoad: string | (() => PoPageDynamicEditOptions);
    /**
     * @optional
     *
     * @description
     *
     * Função que será executada após ser realizada a busca dos dados.
     *
     * A propriedade aceita os seguintes tipos:
     * - `function`: Método que será executado.
     *
     * Esta função passa por parâmetro o model e deve recebê-lo de volta com as alterações.
     * Também aceita o retorno de um Observable com o novo model.
     *
     * Por exemplo:
     *
     * ```
     * onLoadCustom(model) {
     *  return { ...model, customField: 'newValue' };
     * }
     *
     * ```
     * Para referenciar a sua função utilize a propriedade `bind`, por exemplo:
     * ```
     *  [p-load-data]="onLoadCustom.bind(this)"
     * ```
     */
    onLoadData: ((model: any) => any) | ((model: any) => Observable<any>);
    model: any;
    readonly detailActions: PoGridRowActions;
    private indexFocus;
    private language;
    private subscriptions;
    private _actions;
    private _componentsSize?;
    private _literals;
    private _autoRouter;
    private _controlFields;
    private _detailFields;
    private _duplicates;
    private _fields;
    private _keys;
    private _pageActions;
    private _notificationType?;
    /**
     * @optional
     *
     * @description
     *
     * Ações da página.
     */
    set actions(value: PoPageDynamicEditActions);
    get actions(): PoPageDynamicEditActions;
    /**
     * @optional
     *
     * @description
     *
     * Objeto com as literais usadas no `po-page-dynamic-edit`.
     *
     * É possivel customizar passando um objeto com todas as literais disponíveis
     * ou passando apenas as literais que deseja customizar
     *
     * ```
     *  const customLiterals: PoPageDynamicEditLiterals = {
     *    detailActionNew: 'Incluir',
     *    pageActionCancel: 'Descartar',
     *    pageActionSave: 'Gravar',
     *    pageActionSaveNew: 'Gravar e incluir',
     *    registerNotFound: 'Nenhum registro encontrado.',
     *    saveNotificationError: 'Campo(s) obrigatório(s) sem preenchimento.',
     *    saveNotificationSuccessSave: 'Item salvo com sucesso.',
     *    saveNotificationSuccessUpdate: 'Item atualizado com sucesso.',
     *    saveNotificationWarning: 'Necessário preencher o formulário corretamente.'
     *  };
     * ```
     *
     * E para carregar as literais customizadas, basta apenas passar o objeto para o componente.
     *
     * ```
     * <po-page-dynamic-edit
     *   [p-literals]="customLiterals">
     * </po-page-dynamic-edit>
     * ```
     *
     * > O valor padrão será traduzido de acordo com o idioma configurado no [`PoI18nService`](/documentation/po-i18n) ou *browser*.
     */
    set literals(value: PoPageDynamicEditLiterals);
    get literals(): PoPageDynamicEditLiterals;
    /**
     * @optional
     *
     * @description
     *
     * Tipo da notificação.
     *
     * É possivel definir o tipo de notificação que será exibido quando houver algum campo inválido no formulário.
     *
     * ```
     * <po-page-dynamic-edit
     *   p-notification-type="warning">
     * </po-page-dynamic-edit>
     * ```
     *
     * > Os valores aceitos são 'warning' e 'error'.
     * @default warning
     */
    set notificationType(value: string);
    get notificationType(): string;
    /**
     * @todo Validar rotas na mão pois se existir uma rota '**' o catch do navigation não funciona.
     *
     * @optional
     *
     * @description
     *
     * Cria automaticamente as rotas de edição (novo/duplicate) e detalhes caso as ações
     * estejam definidas nas ações.
     *
     * > Para o correto funcionamento não pode haver nenhum rota coringa (`**`) especificada.
     *
     * @default false
     */
    set autoRouter(value: boolean);
    get autoRouter(): boolean;
    /** Lista dos campos usados na tabela e busca avançada. */
    set fields(value: Array<PoPageDynamicEditField>);
    get fields(): Array<PoPageDynamicEditField>;
    /**
     * @optional
     *
     * @description
     *
     * Define o tamanho dos componentes de formulário no template:
     * - `small`: aplica a medida small de cada componente (disponível apenas para acessibilidade AA).
     * - `medium`: aplica a medida medium de cada componente.
     *
     * > Caso a acessibilidade AA não esteja configurada, o tamanho `medium` será mantido.
     * Para mais detalhes, consulte a documentação do [po-theme](https://po-ui.io/documentation/po-theme).
     *
     * @default `medium`
     */
    set componentsSize(value: string);
    get componentsSize(): string;
    constructor(router: Router, activatedRoute: ActivatedRoute, poNotification: PoNotificationService, poDialogService: PoDialogService, poPageDynamicService: PoPageDynamicService, poPageCustomizationService: PoPageCustomizationService, poPageDynamicEditActionsService: PoPageDynamicEditActionsService, poThemeService: PoThemeService, languageService: PoLanguageService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    detailActionNew(): void;
    /**
     * Método que exibe `additionalHelpTooltip` ou executa a ação definida em `additionalHelp`.
     * Para isso, será necessário configurar uma tecla de atalho utilizando o evento `keydown`.
     *
     * ```
     * import { PoPageDynamicEditModule } from '@po-ui/ng-templates';
     * ...
     * @ViewChild('dynamicEdit', { static: true }) dynamicEdit: PoPageDynamicEditComponent;
     *
     * fields: Array<PoPageDynamicEditField> = [
     *  {
     *    property: 'name',
     *    ...
     *    help: 'Mensagem de ajuda.',
     *    additionalHelpTooltip: 'Mensagem de ajuda complementar.',
     *    keydown: this.onKeyDown.bind(this, 'name')
     *  },
     * ]
     *
     * onKeyDown(property: string, event: KeyboardEvent): void {
     *  if (event.code === 'F9') {
     *    this.dynamicEdit.showAdditionalHelp(property);
     *  }
     * }
     * ```
     *
     * @param { string } property Identificador da coluna.
     */
    showAdditionalHelp(property: string): void;
    get duplicates(): any[];
    get keys(): any[];
    get pageActions(): PoPageAction[];
    get controlFields(): any[];
    get detailFields(): any[];
    private loadDataFromAPI;
    private cancel;
    private formatUniqueKey;
    private goBack;
    private executeBackAction;
    private loadData;
    private beforeSetModel;
    private loadOptionsOnInitialize;
    private focusCheckboxInput;
    private focusControl;
    private focusRadioInput;
    private getPoDynamicPageOptions;
    private getMetadata;
    private markControlsAsDirtyAndFocusFirstInvalid;
    private navigateTo;
    private resolveUniqueKey;
    private resolveUrl;
    private executeSave;
    private updateModel;
    private showNotification;
    private saveOperation;
    private save;
    private executeSaveNew;
    private getKeysByFields;
    private getControlFields;
    private getDetailFields;
    private getDuplicatesByFields;
    private getPageActions;
    private isObject;
    static ɵfac: i0.ɵɵFactoryDeclaration<PoPageDynamicEditComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PoPageDynamicEditComponent, "po-page-dynamic-edit", never, { "breadcrumb": { "alias": "p-breadcrumb"; "required": false; }; "serviceApi": { "alias": "p-service-api"; "required": false; }; "title": { "alias": "p-title"; "required": false; }; "onLoad": { "alias": "p-load"; "required": false; }; "onLoadData": { "alias": "p-load-data"; "required": false; }; "actions": { "alias": "p-actions"; "required": false; }; "literals": { "alias": "p-literals"; "required": false; }; "notificationType": { "alias": "p-notification-type"; "required": false; }; "autoRouter": { "alias": "p-auto-router"; "required": false; }; "fields": { "alias": "p-fields"; "required": false; }; "componentsSize": { "alias": "p-components-size"; "required": false; }; }, {}, never, never, false, never>;
}
